==> directfb_1.4.3.orig.tar.gz: DirectFB-1.4.3/systems/x11/glx_surface_pool.h <==
/*
   (c) Copyright 2001-2009  The world wide DirectFB Open Source Community (directfb.org)
   (c) Copyright 2000-2004  Convergence (integrated media) GmbH

   All rights reserved.

   Written by Denis Oliver Kropp <dok@directfb.org>,
              Andreas Hundt <andi@fischlustig.de>,
              Sven Neumann <neo@directfb.org>,
              Ville Syrjälä <syrjala@sci.fi> and
              Claudio Ciccani <klan@users.sf.net>.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __X11SYSTEM__GLX_SURFACE_POOL_H__
#define __X11SYSTEM__GLX_SURFACE_POOL_H__


#include <GL/glx.h>

#include <gl/gl_gfxdriver.h>

#include <core/surface_pool.h>

extern const SurfacePoolFuncs glxSurfacePoolFuncs;


typedef struct {
     int            magic;

     /* Shared resource */
     Pixmap         pixmap;
     int            depth;
} glxAllocationData;

typedef struct {
     int            magic;

     GLBufferData   buffer;

     /* Shared resource */
     Pixmap         pixmap;

     /* Process local data */
     GC             gc;

     GLXFBConfig    config;
     GLXDrawable    drawable;

     /* Bound to a thread's context? */
     GLXContext     current;
     GLXContext     bound;
} LocalPixmap;

typedef struct {
     Display       *display;

     /* Thread local data */
     GLXContext     context;

     GLXDrawable    drawable;
} ThreadContext;

#endif

==> directfb_1.7.7.orig.tar.gz: DirectFB-1.7.7/systems/x11/glx_surface_pool.h <==
/*
   (c) Copyright 2012-2013  DirectFB integrated media GmbH
   (c) Copyright 2001-2013  The world wide DirectFB Open Source Community (directfb.org)
   (c) Copyright 2000-2004  Convergence (integrated media) GmbH

   All rights reserved.

   Written by Denis Oliver Kropp <dok@directfb.org>,
              Andreas Shimokawa <andi@directfb.org>,
              Marek Pikarski <mass@directfb.org>,
              Sven Neumann <neo@directfb.org>,
              Ville Syrjälä <syrjala@sci.fi> and
              Claudio Ciccani <klan@users.sf.net>.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/



#ifndef __X11SYSTEM__GLX_SURFACE_POOL_H__
#define __X11SYSTEM__GLX_SURFACE_POOL_H__


#include <GL/glx.h>

#include <gl/gl_gfxdriver.h>

#include <core/surface_pool.h>

extern const SurfacePoolFuncs glxSurfacePoolFuncs;


typedef struct {
     int            magic;

     /* Shared resource */
     Pixmap         pixmap;
     int            depth;
} glxAllocationData;

typedef struct {
     int            magic;

     GLBufferData   buffer;

     /* Shared resource */
     Pixmap         pixmap;

     /* Process local data */
     GC             gc;

     GLXFBConfig    config;
     GLXDrawable    drawable;

     /* Bound to a thread's context? */
     GLXContext     current;
     GLXContext     bound;
} LocalPixmap;

typedef struct {
     Display       *display;

     /* Thread local data */
     GLXContext     context;

     GLXDrawable    drawable;
} ThreadContext;

#endif
